/* bender - pitch-shift an input file according to a glissando curve.

   The pitch-shifting isn't fancy -- it doesn't let you retain the
   duration of the input file, as you could with a phase vocoder.
   (This is an adaptation of Lansky's vreadin instrument.)

   p0 = output start time
   p1 = input start time
   p2 = output duration
   p3 = overall amplitude (scales envelope curve)
   p4 = glissando scaler [optional]
   p5 = stereo spread (if input is mono) [optional]

   Assumes function table 1 is amplitude curve for the note. (Try gen 18.)
   Or you can just call setline. If no setline or function table 1, uses
   flat amplitude curve.

   Assumes function table 2 is glissando curve. This should be time,transp
   pairs, where transp is number of semitones (positive or negative) to
   transpose. Gen 18 works for this. For example, if you give the following
   makegen for a sustained A440 note, the output will gliss up to B and
   then down to G, where it will hold until the end.

       makegen(2, 18, 1000, 0,0, 1,2, 2,-2, 3,-2)

   By default, these curves are consulted 1000 times per second, but this
   can be changed by calling reset() with a different value.

   If p4 (glissando scaler) is non-zero, then the glissando curve will be
   multiplied by this factor. (Try using makegen(2, 20, outdur*10, 1) to
   make the glissando array out of random numbers that change 10 times per
   second. Then scale this by 5 to make the pitch jumps extreme. Make p4
   negative to invert the shape of the gliss.)

   If you see "reached eof on input file" right after a call to bender,
   it means the note tried to read past the end of the input file. Most
   likely, the end of sound will be abrupt, since the envelope curve
   will not have run its full course. Try shortening the output duration
   (p2) or starting to read earlier on the input file (p1).


   semicps - a conversion function useful in making the glissando curve.

   Given two frequencies (in Hz), returns the number of equal-tempered
   semitones by which to transpose the first in order to get the second.

   John Gibson (jgg9c@virginia.edu), 9/20/98, rev. 6/21/99
*/
load("bender")

system("rm -f bender1.snd")
system("I2 bender1.snd")
output("bender1.snd")

input("your.snd")

outskip = 0.0
outdur = 2.0
inskip = 0.0
amp = 1.0
glisscaler = 1.0
spread = 0.5

setline(0,0, 1,1, 9,1, 10,0)
makegen(2, 18, 1000, 0,0, 1,2, 2,-2)

bender(outskip, inskip, outdur, amp, glisscaler, spread)

